@@ -90,6 +90,8 @@ def _expand_dims(data, axis):
 def size(a=None):
     """Returns the number of elements"""
     if a is None: return 0
+    if type(a) is str:
+        return 1
     try:
         return len(a)
     except:
@@ -1477,12 +1479,21 @@ def slope(array):
     return array[1:n]-array[0:n-1]
 
 
-def smooth(y, width):
+def smooth(y, width, fillvalue=np.nan):
     """ Smooth a curve"""
-    cumsum_vec = np.cumsum(np.insert(y, 0, 0)) 
-    ma_vec = (cumsum_vec[width:] - cumsum_vec[:-width]) / width
-    #box = np.ones(box_pts)/box_pts
-    #y_smooth = np.convolve(y, box, mode='same')
+    if y.ndim==1:
+        cumsum_vec = np.cumsum(np.insert(y, 0, 0)) 
+        ma_vec = (cumsum_vec[width:] - cumsum_vec[:-width]) / width
+        #box = np.ones(box_pts)/box_pts
+        #y_smooth = np.convolve(y, box, mode='same')
+    else:
+        # Do each axis separately
+        # https://gist.github.com/kwinkunks/769e39e8314b5479842a77b18e4e3eda
+        kernel = np.ones(width) / width
+        def convfunc(arr1d):
+            return np.convolve(arr1d, kernel, mode='same')
+        first_pass = np.apply_along_axis(convfunc, axis=0, arr=y)
+        ma_vec = np.apply_along_axis(convfunc, axis=1, arr=first_pass)
     return ma_vec
 
 # Gaussian filter
@@ -1865,23 +1876,74 @@ def match(a,b,epsilon=0):
     return suba, subb
 
 # Interpolation with extrapolation
-def interp(x,y,xout,kind='cubic',bounds_error=False,assume_sorted=True,extrapolate=True,exporder=2,fill_value=np.nan):
-    yout = interp1d(x,y,kind=kind,bounds_error=bounds_error,fill_value=(fill_value,fill_value),assume_sorted=assume_sorted)(xout)
+def interp(x,y,xout,kind='cubic',bounds_error=False,assume_sorted=True,
+           extrapolate=True,exporder=2,fill_value=np.nan):
+    """
+    Interpolate data using scipy.interpolate.interp1d.  This function allows for
+    extrapolation on the ends as well.
+
+    Parameters
+    ----------
+    x : numpy array
+       Array of x-values to fit.
+    y : numpy array
+       Array of y-values to fit.
+    xout : numpy array
+       Array or scalar of desired output x-values.
+    kind : str, optional
+       The order of the interpolation: 'linear', 'quadratic', or 'cubic'.
+         Default is 'cubic'.
+    bounds_error : boolean, optional
+       Throw an exception if the requested values are outside the data range.
+         Default is False.
+    assume_sorted : boolean, optional
+       Assume that the x-values are sorted.  Default is True.
+    extrapolate : bool, optional
+       Extrapolate requested values outside of the data range.  Default is True.
+    exporder : int, optional
+       The extrapolation polynomial order.  Default is 2.
+    fill_value : float, optional
+       The fill value to use for requested points outside of the data range.
+
+    Returns
+    -------
+    yout : numpy array
+       Interpolated y-values.
+
+    Example
+    -------
+
+    yout = interp(x,y,xout)
+
+    """
+
+    xo = np.atleast_1d(xout)
+    
+    # X must be unique and sorted
+    if assume_sorted==False:
+        u,ui = np.unique(x,return_index=True)
+        si = ui[np.argsort(x[ui])]
+    else:
+        si = np.arange(len(x))
+    # Run scipy.interpolate.interp1d
+    yout = interp1d(x[si],y[si],kind=kind,bounds_error=bounds_error,
+                    fill_value=(fill_value,fill_value),assume_sorted=assume_sorted)(xo)
     # Need to extrapolate
-    if ((np.min(xout)<np.min(x)) | (np.max(xout)>np.max(x))) & (extrapolate is True):
-        si = np.argsort(x)
+    if ((np.min(xo)<np.min(x)) | (np.max(xo)>np.max(x))) & (extrapolate is True):
+        u,ui = np.unique(x,return_index=True)
+        si = ui[np.argsort(x[ui])]
         npix = len(x)
         nfit = np.min([np.maximum(exporder+1,1),npix])
         # At the beginning
-        if (np.min(xout)<np.min(x)):
+        if (np.min(xo)<np.min(x)):
             coef1 = poly_fit(x[0:nfit], y[0:nfit], exporder)
-            bd1, nbd1 = where(xout < np.min(x))
-            yout[bd1] = poly(xout[bd1],coef1)
+            bd1, nbd1 = where(xo < np.min(x))
+            yout[bd1] = poly(xo[bd1],coef1)
         # At the end
-        if (np.max(xout)>np.max(x)):
+        if (np.max(xo)>np.max(x)):
             coef2 = poly_fit(x[npix-nfit:], y[npix-nfit:], exporder)
-            bd2, nbd2 = where(xout > np.max(x))
-            yout[bd2] = poly(xout[bd2],coef2)     
+            bd2, nbd2 = where(xo > np.max(x))
+            yout[bd2] = poly(xo[bd2],coef2)     
     return yout
 
 def concatenate(a,b=None):
@@ -2505,9 +2567,8 @@ def help(*args,verbose=False):
             colnames = a.columns
             dtype = a.dtype
             tab = True
-            
-        # Short output
-        if verbose==False or tab==False:
+
+        if tab==False:
             fmt = '%-16s %-22s %-10s'
             if atype == np.ndarray and a.dtype.names is None:
                 atype = '<np.ndarray '+str(a.dtype)+'>'
@@ -2520,7 +2581,14 @@ def help(*args,verbose=False):
                     sshape = '['+','.join(np.char.array(shape).astype(str))+']'
                 data = (varnames[i],atype,sshape)
             else:
-                data = (varnames[i],atype,'['+str(na)+']')
+                data = (varnames[i],atype,'['+str(na)+']')            
+        else:
+            fmt = '%-16s %-22s %-10s'
+            data = (varnames[i],type(a),'['+str(na)+']')
+                
+        # Short output
+        if verbose==False:
+            fmt = '%-16s %-22s %-10s'
             if len(varnames[i])>16:
                 print(varnames[i])
                 print(fmt % ('',data[1],data[2]))
@@ -2529,17 +2597,28 @@ def help(*args,verbose=False):
 
         # Verbose output of table
         else:
-            print(str(type(a))+', '+str(len(colnames))+' columns, ['+str(na)+']')
-            fmt = '%-20s %-10s %-20s'                    
-            for j in range(len(colnames)):
-                col = a[colnames[j]][0]
-                if size(col)>1:
-                    data = (colnames[j],dtype[j].base,'Array['+str(size(col))+']')           
-                else:
-                    data = (colnames[j],dtype[j].base,str(col))
-                if len(colnames[j])>16:
-                    print(colnames[j])
+            if tab==False:
+                fmt = '%-16s %-22s %-10s'
+                if len(varnames[i])>16:
+                    print(varnames[i])
                     print(fmt % ('',data[1],data[2]))
+                    print(str(a))
                 else:
                     print(fmt % data)
+                    print(str(a))
+                    
+            else:
+                print(str(type(a))+', '+str(len(colnames))+' columns, ['+str(na)+']')
+                fmt = '%-20s %-10s %-20s'                    
+                for j in range(len(colnames)):
+                    col = a[colnames[j]][0]
+                    if size(col)>1 and type(col) != str:
+                        data = (colnames[j],dtype[j].base,'Array['+str(size(col))+']')           
+                    else:
+                        data = (colnames[j],dtype[j].base,str(col))
+                    if len(colnames[j])>16:
+                        print(colnames[j])
+                        print(fmt % ('',data[1],data[2]))
+                    else:
+                        print(fmt % data)
 
